@@ -23,19 +23,19 @@
 #' @return A tibble with details on all listed bathrooms.
 #' @export
 #'
-#' @examples \donttest{
-#'
+#' @examples
+#' \donttest{
+#' 
 #' a <- rfg_all_restrooms(accessible = TRUE, unisex = TRUE)
-#'
 #' }
-
+#' 
 rfg_all_restrooms <- function(accessible = FALSE, unisex = FALSE,
                               verbose = TRUE, tidy = FALSE) {
   ada_query <- ada_function(accessible)
 
   unisex_query <- unisex_function(unisex)
 
-  query <- paste0(base_url, ".json?", ada_query, unisex_query, "&per_page=1")
+  query <- paste0(base_url, ".json?", ada_query, unisex_query, "per_page=1")
 
   df <- query_looper(query, verbose, tidy)
 
