@@ -13,12 +13,12 @@
 #' @return A tibble with details of any and all nearby refuge bathrooms.
 #' @export
 #'
-#' @examples \donttest{
-#'
-#' c <- rfg_location(lat=39, lng=-75)
-#'
+#' @examples
+#' \donttest{
+#' 
+#' c <- rfg_location(lat = 39, lng = -75)
 #' }
-
+#' 
 rfg_location <- function(lat, lng, accessible = FALSE,
                          unisex = FALSE, verbose = TRUE, tidy = FALSE) {
   if (missing(lat) || missing(lng)) {
@@ -31,11 +31,11 @@ rfg_location <- function(lat, lng, accessible = FALSE,
 
   unisex_query <- unisex_function(unisex)
 
-  coords <- paste0("lat=", lat, "&lng=", lng)
+  coords <- paste0("lat=", lat, "&lng=", lng, "&")
 
   query <- paste0(
     base_url, "/by_location.json?", coords, ada_query,
-    unisex_query, "&per_page=1"
+    unisex_query, "per_page=1"
   )
 
   df <- query_looper(query, verbose, tidy)
